@@ -1,4 +1,5 @@
 import os
+from typing import Any, Dict
 
 import torch
 from ray.serve import Application
@@ -6,7 +7,7 @@ from ray.serve import Application
 from ray_embedding.dto import AppConfig, ModelDeploymentConfig, DeployedModel, NodeReaperConfig
 from ray_embedding.embedding_model import EmbeddingModel
 from ray_embedding.node_reaper import NodeReaper, NODE_REAPER_DEPLOYMENT_NAME
-from ray_embedding.utils import node_affinity_for_head, node_affinity_for_worker
+from ray_embedding.utils import get_head_node_id
 from ray_embedding.model_router import ModelRouter
 
 
@@ -56,7 +57,7 @@ def build_app(args: AppConfig) -> Application:
 
     node_reaper_config = args.node_reaper or NodeReaperConfig()
 
-    node_reaper_kwargs = {
+    node_reaper_kwargs: Dict[str, Any] = {
         "ssh_user": node_reaper_config.ssh_user,
         "ssh_private_key": node_reaper_config.ssh_private_key,
     }
@@ -65,15 +66,16 @@ def build_app(args: AppConfig) -> Application:
     if node_reaper_config.reap_interval_seconds is not None:
         node_reaper_kwargs["reap_interval_seconds"] = node_reaper_config.reap_interval_seconds
 
-    node_reaper = NodeReaper.options(
+    _, head_node_ip = get_head_node_id()
+    node_reaper = NodeReaper.options( 
         name=NODE_REAPER_DEPLOYMENT_NAME,
-        ray_actor_options={"scheduling_strategy": node_affinity_for_head()},
+        ray_actor_options={"num_cpus": 0.25, f"node:{head_node_ip}": 1},
+        autoscaling_config={"initial_replicas": 1, "min_replicas": 1, "max_replicas": 1}
     ).bind(**node_reaper_kwargs)
 
     deployed_models = {model_config.served_model_name: build_model(model_config, node_reaper) for model_config in models}
     router = ModelRouter.options(
-        name=model_router.deployment,
-        ray_actor_options={"scheduling_strategy": node_affinity_for_worker()}
+        name=model_router.deployment
     ).bind(deployed_models, model_router.path_prefix, node_reaper)
     
     return router
