@@ -47,7 +47,7 @@ class NodeReaperConfig(BaseModel):
 
 class AppConfig(BaseModel):
     model_router: ModelRouterConfig
-    node_reaper: NodeReaperConfig
+    node_reaper: Optional[NodeReaperConfig] = None
     models: List[ModelDeploymentConfig]
     
 
