@@ -4,20 +4,20 @@ import time
 from typing import Optional, Dict, List, Tuple
 
 from fastapi import FastAPI, HTTPException
+import ray
 from ray import serve
 from ray.serve.handle import DeploymentHandle
-from ray.util import get_node_ip_address
 
 from ray_embedding.dto import DeployedModel, EmbeddingRequest, EmbeddingResponse
+from ray_embedding.utils import get_current_node_ip
 
 web_api = FastAPI(title="Ray Embeddings - OpenAI-compatible API")
 
 @serve.deployment
 @serve.ingress(web_api)
 class ModelRouter:
-    def __init__(self, deployed_models: Dict[str, DeployedModel],
-                 path_prefix: List[str], max_concurrency: Optional[int] = 32,
-                 node_health_tracker: Optional[DeploymentHandle] = None):
+    def __init__(self, deployed_models: Dict[str, DeployedModel], path_prefix: List[str],
+                 max_concurrency: Optional[int] = 32, node_reaper: Optional[DeploymentHandle] = None):
         assert deployed_models, "models cannot be empty"
         assert path_prefix, "path_prefix cannot be empty"
 
@@ -35,13 +35,7 @@ class ModelRouter:
              "permission": []} for item in self.deployed_models.keys()
         ]
         self.logger.info(f"Successfully registered models: {self.available_models}")
-        self.node_health_tracker = node_health_tracker
-        replica_context = serve.get_replica_context()
-        self.deployment_name = replica_context.deployment
-        self.replica_actor_name = replica_context.replica_id.to_full_id_str()
-        self.node_ip = get_node_ip_address()
-        self.logger.info(f"Successfully initialized model router. "
-                         f"Deployment name: {self.deployment_name}, Replica actor name: {self.replica_actor_name}, Node IP: {self.node_ip}")
+        self.node_reaper = node_reaper
 
     async def _compute_embeddings_from_resized_batches(self, model: str, inputs: List[str], dimensions: Optional[int] = None):
         deployed_model = self.deployed_models[model]
@@ -122,7 +116,19 @@ class ModelRouter:
             raise HTTPException(status_code=400, detail=f"The API path prefix specified is invalid: '{path_prefix}'")
         return {"object": "list", "data": self.available_models}
 
-    async def check_health(self):
-        if self.node_health_tracker:
-            if await self.node_health_tracker.is_bad_gpu_or_no_model_replica_on_node.remote(self.node_ip):
-                raise RuntimeError(f"The node {self.node_ip} is marked bad, or no model replica running on the node.")
+    def check_health(self):
+        if not self.node_reaper:
+            return
+
+        try:
+            unhealthy_node_ips = ray.get(self.node_reaper.get_unhealthy_node_ips.remote())
+        except Exception as exc:
+            self.logger.warning(f"Unable to fetch node reaper data: {exc}")
+            return
+
+        if not unhealthy_node_ips:
+            return
+
+        node_ip = get_current_node_ip()
+        if node_ip and node_ip in unhealthy_node_ips:
+            raise RuntimeError("Model router replica is colocated with an unhealthy embedding replica node.")
